#' DesignLibrary: A package for creating designs
#'
#' 
#' 
#' @docType package
#' 
#' @name DesignLibrary
#' 
#' @importFrom utils globalVariables
#' 
#' 


globalVariables(
  names = c(
    "A",
    "B",
    "bias",
    "block",
    "blocks",
    "causal_process",
    "cluster",
    "clusters",
    "e1",
    "e2",
    "G",
    "latent",
    "M",
    "M_Z_0",
    "M_Z_1",
    "N",
    "n",
    "noise",
    "outcome_sd",
    "posterior_H",
    "R",
    "R_Z_0",
    "R_Z_1",
    "sensitive_trait",
    "setNames",
    "test_results",
    "type",
    "u",
    "u_0",
    "u_a",
    "u_R",
    "u_t1",
    "u_W",
    "U_Z", 
    "withholder",
    "X",
    "Y",
    "Y_A_0_B_0",
    "Y_A_0_B_1",
    "Y_A_1_B_0",
    "Y_A_1_B_1",
    "Y_M_0_Z_0",
    "Y_M_0_Z_1",
    "Y_M_1_Z_0",
    "Y_M_1_Z_1",
    "Y_nat0",
    "Y_nat0_Z_0",
    "Y_nat0_Z_1",
    "Y_nat1",
    "Y_nat1_Z_0",
    "Y_nat1_Z_1",
    "Y_t1",
    "Y_t2",
    "Y_t2_Z_0",
    "Y_t2_Z_1",
    "Y_X_0", 
    "Y_X_1",
    "Y_Z_0",
    "Y_Z_1",
    "Z_cond_prob",
    "Z",
    "zeros",
    "u_Z",
    "sd"
    ))
